@@ -1,4 +1,4 @@
-﻿setlabel <- function (M_ID, M) 
+setlabel <- function (M_ID, M) 
 {
   L <- NaN
   for (i in 1:length(M)) {
